@@ -43,10 +43,10 @@ fn bls12_377_gadget_bilinearity_test() {
 
     let a: G1Projective = G1Projective::prime_subgroup_generator();
     let b: G2Projective = G2Projective::prime_subgroup_generator();
-    let s: Fr = Fr::one() + &Fr::one();
+    let s: Fr = Fr::one() + Fr::one();
 
-    let sa = a.mul(&s);
-    let sb = b.mul(&s);
+    let sa = a.mul(s);
+    let sb = b.mul(s);
 
     let a_g = G1Gadget::alloc(&mut cs.ns(|| "a"), || Ok(a)).unwrap();
     let b_g = G2Gadget::alloc(&mut cs.ns(|| "b"), || Ok(b)).unwrap();
